@@ -813,10 +813,12 @@ Initate block masks.
 */
 void bowl_init_block_masks() 
 {
+	int masksize = sizeof(block_masks[0].mask); // same for all
+
 	block_masks[0].rx = 0;
 	block_masks[0].ry = 0;
 	block_masks[0].id = 0;
-	memset(block_masks[0].mask, 0, sizeof( int ) * 4 * 4 * 4 );
+	memset(block_masks[0].mask, 0, masksize );
 	block_masks[0].mask[0][1][1] = 1;
 	block_masks[0].mask[0][2][1] = 1;
 	block_masks[0].mask[0][1][2] = 1;
@@ -837,7 +839,7 @@ void bowl_init_block_masks()
 	block_masks[1].rx = 0;
 	block_masks[1].ry = 0;
 	block_masks[1].id = 1;
-	memset(block_masks[1].mask, 0, sizeof( int ) * 4 * 4 * 4 );
+	memset(block_masks[1].mask, 0, masksize );
 	block_masks[1].mask[0][0][2] = 1;
 	block_masks[1].mask[0][1][2] = 1;
 	block_masks[1].mask[0][2][2] = 1;
@@ -858,7 +860,7 @@ void bowl_init_block_masks()
 	block_masks[2].rx = 0;
 	block_masks[2].ry = 1;
 	block_masks[2].id = 2;
-	memset(block_masks[2].mask, 0, sizeof( int ) * 4 * 4 * 4 );
+	memset(block_masks[2].mask, 0, masksize );
 	block_masks[2].mask[0][0][1] = 1;
 	block_masks[2].mask[0][1][1] = 1;
 	block_masks[2].mask[0][2][1] = 1;
@@ -879,7 +881,7 @@ void bowl_init_block_masks()
 	block_masks[3].rx = 0;
 	block_masks[3].ry = 1;
 	block_masks[3].id = 3;
-	memset(block_masks[3].mask, 0, sizeof( int ) * 4 * 4 * 4 );
+	memset(block_masks[3].mask, 0, masksize );
 	block_masks[3].mask[0][0][2] = 1;
 	block_masks[3].mask[0][1][1] = 1;
 	block_masks[3].mask[0][1][2] = 1;
@@ -900,7 +902,7 @@ void bowl_init_block_masks()
 	block_masks[4].rx = 0;
 	block_masks[4].ry = 1;
 	block_masks[4].id = 4;
-	memset(block_masks[4].mask, 0, sizeof( int ) * 4 * 4 * 4 );
+	memset(block_masks[4].mask, 0, masksize );
 	block_masks[4].mask[0][0][1] = 1;
 	block_masks[4].mask[0][1][1] = 1;
 	block_masks[4].mask[0][1][2] = 1;
@@ -921,7 +923,7 @@ void bowl_init_block_masks()
 	block_masks[5].rx = 0;
 	block_masks[5].ry = 1;
 	block_masks[5].id = 5;
-	memset(block_masks[5].mask, 0, sizeof( int ) * 4 * 4 * 4 );
+	memset(block_masks[5].mask, 0, masksize );
 	block_masks[5].mask[0][0][1] = 1;
 	block_masks[5].mask[0][1][1] = 1;
 	block_masks[5].mask[0][2][1] = 1;
@@ -942,7 +944,7 @@ void bowl_init_block_masks()
 	block_masks[6].rx = 0;
 	block_masks[6].ry = 1;
 	block_masks[6].id = 6;
-	memset(block_masks[6].mask, 0, sizeof( int ) * 4 * 4 * 4 );
+	memset(block_masks[6].mask, 0, masksize );
 	block_masks[6].mask[0][2][2] = 1;
 	block_masks[6].mask[0][0][1] = 1;
 	block_masks[6].mask[0][1][1] = 1;
