@@ -27,7 +27,8 @@ enum {
     GAME_VS_CPU,
     GAME_VS_HUMAN_HUMAN,
     GAME_VS_HUMAN_CPU,
-    GAME_VS_CPU_CPU
+    GAME_VS_CPU_CPU,
+    GAME_LAST
 };
 
 typedef struct {
