@@ -30,6 +30,7 @@ int term_game = 0;
 extern Sdl sdl;
 extern Config config;
 extern char gametype_names[8][64];
+extern char gametype_ids[8][64];
 
 int main(int argc, char *argv[])
 {
@@ -52,7 +53,16 @@ int main(int argc, char *argv[])
 
     set_random_seed(); /* set random seed */
 
-    /* game tpyes */
+    /* game ids - not translated to be fixed independant of language */
+    strcpy(gametype_ids[0],"demo");
+    strcpy(gametype_ids[1],"classic");
+    strcpy(gametype_ids[2],"figures");
+    strcpy(gametype_ids[3],"vshuman");
+    strcpy(gametype_ids[4],"vscpu");
+    strcpy(gametype_ids[5],"vshumanhuman");
+    strcpy(gametype_ids[6],"vshumancpu");
+    strcpy(gametype_ids[7],"vscpucpu");
+    /* game names - translated for display */
     strcpy(gametype_names[0],_("Demo"));
     strcpy(gametype_names[1],_("Classic"));
     strcpy(gametype_names[2],_("Figures"));
