@@ -545,7 +545,7 @@ Font* load_font(char *fname)
         fnt->char_offset[i] = fnt->char_offset[i - 1] + fnt->char_width[i - 1];
 
     /* allowed keys */
-    memset(fnt->keys, 0, 256);
+    memset(fnt->keys, 0, sizeof(fnt->keys));
     for (i = 0; i < fnt->length; i++) {
         fnt->keys[i + fnt->offset] = 1;
     }
@@ -592,7 +592,7 @@ Font *load_fixed_font(char *f, int off, int len, int w)
         fnt->char_offset[i] = fnt->char_offset[i - 1] + w;
 	
     /* allowed keys*/
-    memset(fnt->keys, 0, 256);
+    memset(fnt->keys, 0, sizeof(fnt->keys));
     for (i = 0; i < fnt->length; i++) {
         fnt->keys[i + fnt->offset] = 1;
     }
