@@ -41,6 +41,7 @@ int  *next_blocks, next_blocks_size = 0; /* buffered game blocks for
 extern Sdl sdl;
 extern Config config;
 extern int term_game;
+extern char gametype_ids[8][64];
 
 /*
 ====================================================================
@@ -351,20 +352,6 @@ void tetris_run()
     int gain_multiplayer_bonus = 0;
     int escape = 0;
     
-    /* HACK: moved due to i18n
-       a game type index is mapped to the specified highscore */
-    char *chart_map[8] = {
-        _("Demo"),
-        _("Classic"),
-        _("Figures"),
-        _("Two-Player"),
-        _("Two-Player"),
-        _("Three-Player"),
-        _("Three-Player"),
-        _("Three-Player")
-    };
-    
-    
     /* count number of bowls */
     bowl_count = 0;
     for ( i = 0; i < BOWL_COUNT; i++ )
@@ -489,7 +476,7 @@ void tetris_run()
     chart_clear_new_entries();
     for ( i = 0; i < BOWL_COUNT; i++ )
         if ( bowls[i] ) 
-            chart_add( chart_set_query( chart_map[config.gametype] ), bowls[i]->name, bowls[i]->level, counter_get( bowls[i]->score ) );
+            chart_add( chart_set_query( gametype_ids[config.gametype] ), bowls[i]->name, bowls[i]->level, counter_get( bowls[i]->score ) );
     SDL_ShowCursor( 1 );
 }
 
@@ -534,8 +521,8 @@ void tetris_make_stat()
     
     /* reset counters */
     total = 0; total_lines = 0;
-    memset( lines, 0, sizeof( int ) * 1024 );
-    memset( scores, 0, sizeof( int ) * 1024 );
+    memset( lines, 0, sizeof( lines ) );
+    memset( scores, 0, sizeof( scores ) );
         
     printf( "Computing: %3i %3i %3i %3i %3i %3i\n", CPU_SCORE_HOLE, CPU_SCORE_ALT, CPU_SCORE_LINE, CPU_SCORE_STEEP, CPU_SCORE_ABYSS, CPU_SCORE_BLOCK );
         
